@@ -4,6 +4,7 @@ import csv
 
 
 class CSV_U(Writer):
+    suffix = 'csv'
 
     def process(self):
         self.processed_data = self.data
@@ -28,5 +29,3 @@ class CSV_U(Writer):
             self.OutputFilesClass.given_filename = base_name
         else:
             raise WriterProcessingIncompleteError("Write called but processing was not marked as complete. Not writing")
-    def suffix(self):
-        return 'csv'
